@@ -1,5 +1,6 @@
 /*
-Copyright 1996, 1997, 1998, 2000, 2001 Free Software Foundation, Inc.
+Copyright 1996, 1997, 1998, 2000, 2001, 2007, 2009 Free Software Foundation,
+Inc.
 
 This file is part of the GNU MP Library.
 
@@ -17,6 +18,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with the GNU MP Library.  If not, see http://www.gnu.org/licenses/.  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include "gmp.h"
 #include "gmp-impl.h"
 
@@ -61,6 +63,7 @@ cputime ()
 #define TIMES OPS/(SIZE+1)
 #endif
 
+int
 main ()
 {
   mp_limb_t nptr[2 * SIZE];
@@ -85,7 +88,7 @@ main ()
 
       mpn_random2 (nptr, nsize);
       mpn_random2 (dptr, dsize);
-      dptr[dsize - 1] |= (mp_limb_t) 1 << (BITS_PER_MP_LIMB - 1);
+      dptr[dsize - 1] |= (mp_limb_t) 1 << (GMP_LIMB_BITS - 1);
 
       MPN_COPY (rptr, nptr, nsize);
       qlimb = mpn_divrem (qptr, (mp_size_t) 0, rptr, nsize, dptr, dsize);
